Struct Target

pub struct Target {
    pub hosts: Vec<Host>,
}

Fields

hosts: Vec<Host>

Implementations

Source

impl Target

pub fn new(hosts: Vec<Host>) -> Target

Scan different ports for different targets, for example, we want to scan ports 22 and 23 of “192.168.1.1” and ports 80 and 81 of “192.168.1.2”, you can define the address and port range of each host yourself.

use pistol::Target;
use pistol::Host;
use std::net::Ipv4Addr;
use std::net::Ipv6Addr;

fn test() {
    let host1 = Host::new(Ipv4Addr::new(192, 168, 72, 135).into(), Some(vec![22, 23]));
    let host2 = Host::new(Ipv6Addr::new(0xfe80, 0x0000, 0x0000, 0x0000, 0x020c, 0x29ff, 0xfeb6, 0x8d99).into(), Some(vec![80, 81]));
    let target = Target::new(vec![host1, host2]);
}
pub fn from_subnet( subnet: &str, ports: Option<Vec<u16>>, ) -> Result<Target, PistolError>

Scan a IPv4 subnet with same ports.

use pistol::Target;
use pistol::Host;
use std::net::Ipv4Addr;

fn test() {
    let target = Target::from_subnet("192.168.1.0/24", Some(vec![22])).unwrap();
}