pub struct PistolCapture { /* private fields */ }Expand description
Save the sent traffic locally in pcapng format. Note that this method does not read the traffic from the network card, but to save the traffic before the it is sent.